@@ -74,6 +74,7 @@ $VERSION = "5.5";
      "pager",
      "password",
      "patch",
+     "perl5lib_verbosity",
      "prefer_installer",
      "prefs_dir",
      "prerequisites_policy",
@@ -90,7 +91,6 @@ $VERSION = "5.5";
      "term_is_latin",
      "term_ornaments",
      "test_report",
-     "threshold_perl5lib_upto",
      "trust_test_report_history",
      "unzip",
      "urllist",
@@ -492,7 +492,11 @@ sub home () {
     # why one load message pops up even when verbosity is turned off.
     # This means File::HomeDir load messages are never seen, but I
     # think that's probably OK -- DAGOLDEN
-    local $CPAN::Config->{load_module_verbosity} = q[none];
+    
+    # 5.6.2 seemed to segfault localizing a value in a hashref 
+    # so do it manually instead
+    my $old_v = $CPAN::Config->{load_module_verbosity};
+    $CPAN::Config->{load_module_verbosity} = q[none];
     if ($CPAN::META->has_usable("File::HomeDir")) {
         $home = File::HomeDir->my_data;
         unless (defined $home) {
@@ -502,6 +506,7 @@ sub home () {
     unless (defined $home) {
         $home = $ENV{HOME};
     }
+    $CPAN::Config->{load_module_verbosity} = $old_v;
     $home;
 }
 
